import * as cheerio from "cheerio";
import { Context } from "./context";
import { kSerializeData } from "../utils";
import { ISkinContext, ISkinContextOptions, Transformation, TransformationUnion } from "../interfaces";
export declare class SkinContext extends Context<ISkinContext> implements ISkinContext {
    /**
     * Skin id
     */
    readonly id: ISkinContext["id"];
    /**
     * Skin name
     */
    readonly name: ISkinContext["name"];
    /**
     * Skin model
     */
    readonly model: ISkinContext["model"];
    /**
     * Skin tags
     */
    readonly tags: ISkinContext["tags"];
    /**
     * Skin rating
     */
    readonly rating: ISkinContext["rating"];
    /**
     * Skin creation timestamp
     */
    readonly createdAt: ISkinContext["createdAt"];
    /**
     * Skin transformation type
     */
    readonly transformation: ISkinContext["transformation"];
    /**
     * Payload loaded
     * @hidden
     */
    private extended;
    /**
     * @hidden
     */
    constructor({ data, type, ...options }: ISkinContextOptions);
    /**
     * Get skin url
     */
    get url(): ISkinContext["url"];
    /**
     * Get skin renders
     */
    get renders(): ISkinContext["renders"];
    /**
     * Check is slim skin model
     */
    get isSlim(): boolean;
    /**
     * Check payload loaded
     */
    get isExtended(): boolean;
    /**
     * Check is transformed
     */
    get isTransformed(): boolean;
    /**
     * Transform skin
     *
     * @see {@link https://namemc.com/skin/ee40191789e621d3 | Check "Tools" card}
     */
    transform(transformation: Transformation | TransformationUnion): Promise<SkinContext>;
    /**
     * Load all skin information
     */
    loadPayload(): Promise<void>;
    /**
     * @hidden
     */
    static parseSkinLink(link: string): Pick<ISkinContext, "id" | "model"> | void;
    /**
     * @hidden
     */
    protected parseSkinRating($: cheerio.CheerioAPI): number;
    /**
     * @hidden
     */
    protected parseSkinTime($: cheerio.CheerioAPI): number;
    /**
     * @hidden
     */
    [kSerializeData](): ISkinContext;
}
